@@ -1,5 +1,5 @@
 from .application import Application
-from .extensions import (AnalyticsExtension, AIExtension,
+from .extensions import (AnalyticsExtension, AIExtension, ContextsExtension,
                          ExtensionBase, ChatExtension, MediaExtension)
 from .client import Client
 from .client_builder import ClientBuilder
