@@ -9,7 +9,7 @@ from lime_python import (ClientChannel, Command, CommandMethod, Envelope,
 
 from .application import Application
 from .extensions import (AIExtension, AnalyticsExtension, ChatExtension,
-                         ExtensionBase, MediaExtension)
+                         ContextsExtension, ExtensionBase, MediaExtension)
 from .receiver import Receiver
 from .utilities import ClassUtilities
 
@@ -76,6 +76,13 @@ class Client:
             self.application.domain
         )
 
+    @property
+    def context_extension(self) -> ContextsExtension:  # noqa: D102
+        return self.__get_extension(
+            ContextsExtension,
+            self.application.domain
+        )
+
     @property
     def listening(self) -> bool:  # noqa: D102
         return self.__listening
